@@ -1,11 +1,8 @@
 
 from dpdispatcher.ssh_context import SSHSession
-import os,sys,time,random,uuid,json
-from typing import Optional
-import dargs
-from dargs import dargs, Argument
+import json
+from dargs import Argument
 
-from dpdispatcher.JobStatus import JobStatus
 from dpdispatcher import dlog
 from dpdispatcher.base_context import BaseContext
 
@@ -18,7 +15,8 @@ script_template="""\
 """
 
 script_env_template="""
-export REMOTE_ROOT={remote_root}
+echo 0 > {flag_job_task_fail}
+REMOTE_ROOT={remote_root}
 test $? -ne 0 && exit 1
 
 {module_unload_part}
@@ -33,7 +31,7 @@ cd {task_work_path}
 test $? -ne 0 && exit 1
 if [ ! -f {task_tag_finished} ] ;then
   {command_env} ( {command} ) {log_err_part}
-  if test $? -eq 0; then touch {task_tag_finished}; fi
+  if test $? -eq 0; then touch {task_tag_finished}; else echo 1 > {flag_job_task_fail};fi
 fi &
 """
 
@@ -42,8 +40,8 @@ cd $REMOTE_ROOT
 test $? -ne 0 && exit 1
 
 wait
-
-touch {job_tag_finished}
+FLAG_JOB_TASK_FAIL=$(cat {flag_job_task_fail})
+if test $FLAG_JOB_TASK_FAIL -eq 0; then touch {job_tag_finished}; else exit 1;fi
 """
 
 class Machine(object):
@@ -57,21 +55,41 @@ class Machine(object):
 
     subclasses_dict = {}
 
-    # def __new__(cls, batch_type, context_type, local_root='./', remote_root=None, remote_profile={}):
-    #     if cls is Machine:
-    #         # instance = object.__new__(batch_type, context_type, local_root, remote_root, remote_profile)
-    #         subcls = cls.subclasses_dict[cls.__name__]
-    #         instance = subcls.__new__(batch_type, context_type, local_root, remote_root, remote_profile)
-    #     else:
-    #         instance = object.__new__(cls)
-    #     return instance
+    def __new__(cls, *args, **kwargs):
+        if cls is Machine:
+            subcls = cls.subclasses_dict[kwargs['batch_type']]
+            instance = subcls.__new__(subcls, *args, **kwargs)
+        else:
+            instance = object.__new__(cls)
+        return instance
 
-    # def __init__(self, batch_type, context_type, local_root='./', remote_root=None, remote_profile={}):
-    #     pass
+    def __init__(self,
+        batch_type=None,
+        context_type=None,
+        local_root=None,
+        remote_root=None,
+        remote_profile={},
+        *,
+        context=None
+    ):
+        if context is None:
+            assert isinstance(self, self.__class__.subclasses_dict[batch_type])
+            context = BaseContext(
+                context_type=context_type,
+                local_root=local_root,
+                remote_root=remote_root,
+                remote_profile=remote_profile
+            )
+        else:
+            pass
+        self.bind_context(context=context)
 
-    def __init__ (self,
-                context):
+    def bind_context(self, context):
         self.context = context
+
+    # def __init__ (self,
+    #             context):
+    #     self.context = context
         # self.uuid_names = uuid_names
         # self.upload_tag_name = '%s_job_tag_upload' % self.context.job_uuid
         # self.finish_tag_name = '%s_job_tag_finished' % self.context.job_uuid
@@ -81,6 +99,7 @@ class Machine(object):
     def __init_subclass__(cls, **kwargs):
         super().__init_subclass__(**kwargs)
         cls.subclasses_dict[cls.__name__]=cls
+        cls.subclasses_dict[cls.__name__.lower()]=cls
         # cls.subclasses.append(cls)
 
     @classmethod
@@ -178,7 +197,10 @@ class Machine(object):
         for k,v in envs.items():
             export_envs_part += f"export {k}={v}\n"
 
+        flag_job_task_fail = job.job_hash + '_flag_job_task_fail'
+
         script_env = script_env_template.format(
+            flag_job_task_fail=flag_job_task_fail,
             remote_root=self.context.remote_root,
             module_unload_part=module_unload_part,
             module_load_part=module_load_part,
@@ -203,8 +225,13 @@ class Machine(object):
             if task.errlog is not None:
                 log_err_part += f"2>>{task.errlog} "
 
-            single_script_command = script_command_template.format(command_env=command_env, 
-                task_work_path=task.task_work_path, command=task.command, task_tag_finished=task_tag_finished,
+            flag_job_task_fail = job.job_hash + '_flag_job_task_fail'
+            single_script_command = script_command_template.format(
+                flag_job_task_fail=flag_job_task_fail,
+                command_env=command_env,
+                task_work_path=task.task_work_path,
+                command=task.command,
+                task_tag_finished=task_tag_finished,
                 log_err_part=log_err_part)
             script_command += single_script_command
 
@@ -213,7 +240,11 @@ class Machine(object):
 
     def gen_script_end(self, job):
         job_tag_finished = job.job_hash + '_job_tag_finished'
-        script_end = script_end_template.format(job_tag_finished=job_tag_finished)
+        flag_job_task_fail = job.job_hash + '_flag_job_task_fail'
+        script_end = script_end_template.format(
+            job_tag_finished=job_tag_finished,
+            flag_job_task_fail=flag_job_task_fail
+        )
         return script_end
 
     def gen_script_wait(self, resources):
