@@ -1,7 +1,6 @@
 
 # %%
-import os,sys,time,random,uuid,json,copy
-from typing import SupportsRound
+import time,random,uuid,json,copy
 
 from dargs.dargs import Argument
 from dpdispatcher.JobStatus import JobStatus
@@ -110,13 +109,13 @@ class Submission(object):
     def register_task(self, task):
         if self.belonging_jobs:
             raise RuntimeError("Not allowed to register tasks after generating jobs."
-                    "submission hash error {self}".format(self))
+                    "submission hash error {self}".format(self=self))
         self.belonging_tasks.append(task)
 
     def register_task_list(self, task_list):
         if self.belonging_jobs:
             raise RuntimeError("Not allowed to register tasks after generating jobs."
-                    "submission hash error {self}".format(self))
+                    "submission hash error {self}".format(self=self))
         self.belonging_tasks.extend(task_list)
     def get_hash(self):
         return sha1(str(self.serialize(if_static=True)).encode('utf-8')).hexdigest()
@@ -150,7 +149,6 @@ class Submission(object):
         self.try_recover_from_json()
         if self.check_all_finished():
             dlog.info('info:check_all_finished: True')
-            pass
         else:
             dlog.info('info:check_all_finished: False')
             self.upload_jobs()
@@ -319,7 +317,11 @@ class Submission(object):
             if self == submission:
                 self.belonging_jobs = submission.belonging_jobs
                 self.bind_machine(machine=self.machine)
-                self = submission.bind_machine(machine=self.machine)
+                dlog.info(f"Find old submission; recover from json; "
+                    f"submission.submission_hash:{submission.submission_hash}; "
+                    f"machine.context.remote_root:{self.machine.context.remote_root}; "
+                    f"submission.work_base:{submission.work_base};")
+                # self = submission.bind_machine(machine=self.machine)
             else:
                 print(self.serialize())
                 print(submission.serialize())
@@ -516,7 +518,7 @@ class Job(object):
             raise RuntimeError("job_state for job {job} is unknown".format(job=self))
 
         if job_state == JobStatus.terminated:
-            dlog.info(f"job: {self.job_hash} terminated; restarting job")
+            dlog.info(f"job: {self.job_hash} {self.job_id} terminated; restarting job")
             if self.fail_count > 3:
                 raise RuntimeError("job:job {job} failed 3 times".format(job=self))
             self.fail_count += 1
